@@ -21,7 +21,12 @@ An class for holding gridded Radar data.
 
 import numpy as np
 from netCDF4 import num2date
-import xarray
+
+try:
+    import xarray
+    _XARRAY_AVAILABLE = True
+except ImportError:
+    _XARRAY_AVAILABLE = False
 
 try:
     import pyproj
@@ -300,8 +305,17 @@ class Grid(object):
             in a one dimensional array.
             
         """
+
+        if not _XARRAY_AVAILABLE:
+            raise MissingOptionalDependency(
+                'Xarray is required to use Grid.to_xarray but is not '
+                 + 'installed!')
+
         lon, lat = self.get_point_longitude_latitude()
-        height = self.point_z['data'][:, 0, 0]
+        z = self.z['data']
+        y = self.y['data']
+        x = self.x['data']
+
         time = np.array([num2date(self.time['data'][0],
                                   self.time['units'])])
         
@@ -311,11 +325,11 @@ class Grid(object):
             data = xarray.DataArray(np.ma.expand_dims(field_data, 0),
                                     dims=('time', 'z', 'y', 'x'),
                                     coords={'time' : (['time'], time),
-                                            'z' : (['z'], height),
-                                            'lat' : (['y', 'x'], lat),
-                                            'lon' : (['y', 'x'], lon),
-                                            'y' : (['y'], lat[:, 0]),
-                                            'x' : (['x'], lon[0, :])})
+                                            'z' : (['z'], z),
+                                            'lat' : (['y'], lat[:, 0]),
+                                            'lon' : (['x'], lon[0, :]),
+                                            'y' : (['y'], y),
+                                            'x' : (['x'], x)})
             for meta in list(self.fields[field].keys()):
                 if meta is not 'data':
                     data.attrs.update({meta: self.fields[field][meta]})
@@ -327,9 +341,10 @@ class Grid(object):
             ds.lat.attrs = [('long_name', 'latitude of grid cell center'),
                             ('units', 'degree_N'),
                             ('standard_name', 'Latitude')]
-            ds.z.attrs = [('long_name', 'height above mean sea level'),
-                          ('units', 'm'),
-                          ('standard_name', 'Height')]
+
+            ds.z.attrs = get_metadata('z')
+            ds.y.attrs = get_metadata('y')
+            ds.x.attrs = get_metadata('x')
             
             ds.z.encoding['_FillValue'] = None
             ds.lat.encoding['_FillValue'] = None
